@@ -268,24 +268,24 @@ coreml.Graph = class {
 
 coreml.Argument = class {
 
-    constructor(name, value, type, visible) {
+    constructor(name, value, type = null, visible = true) {
         this.name = name;
         this.value = value;
-        this.type = type || null;
-        this.visible = visible !== false;
+        this.type = type;
+        this.visible = visible;
     }
 };
 
 coreml.Value = class {
 
-    constructor(name, type, description, initializer) {
+    constructor(name, type, description = null, initializer = null) {
         if (typeof name !== 'string') {
             throw new coreml.Error(`Invalid value identifier '${JSON.stringify(name)}'.`);
         }
         this.name = name;
         this.type = !type && initializer ? initializer.type : type;
-        this.description = description || null;
-        this.initializer = initializer || null;
+        this.description = description;
+        this.initializer = initializer;
         this.quantization = initializer ? initializer.quantization : null;
     }
 };
