@@ -246,9 +246,9 @@ executorch.TensorType = class {
             case ScalarType.HALF: this.dataType = 'float16'; break;
             case ScalarType.FLOAT: this.dataType = 'float32'; break;
             case ScalarType.DOUBLE: this.dataType = 'float64'; break;
-            case 8: this.dataType = 'complex32'; break;
-            case 9: this.dataType = 'complex64'; break;
-            case 10: this.dataType = 'complex128'; break;
+            case 8: this.dataType = 'complex<float16>'; break;
+            case 9: this.dataType = 'complex<float32>'; break;
+            case 10: this.dataType = 'complex<float64>'; break;
             case ScalarType.BOOL: this.dataType = 'boolean'; break;
             case ScalarType.QINT8: this.dataType = 'qint8'; break;
             case ScalarType.QUINT8: this.dataType = 'quint8'; break;
